..
  This file describes user-visible changes between the versions.

  subsections could include these headings (in this order), omit if no content

    Notice
    Breaking Changes
    New Features and/or Enhancements
    Fixes
    Maintenance
    Deprecations
    Contributors

Change History
##############

..
   1.0.2
   ******

   release expected TBA

1.0.1
******

released 2022-11-27

Maintenance
-----------

* Removed unnecessary run-time packagaing requirements.

1.0.0
******

Initial project release: 2022-11-26
